@@ -8,7 +8,7 @@ import sys
 from mdpo.cli import (
     add_common_cli_first_arguments,
     add_common_cli_latest_arguments,
-    parse_command_aliases_cli_argument,
+    parse_command_aliases_cli_arguments,
     parse_list_cli_argument,
 )
 from mdpo.po2md import pofile_to_markdown
@@ -86,7 +86,7 @@ def parse_options(args):
     if opts.ignore:
         opts.ignore = parse_list_cli_argument(opts.ignore)
 
-    opts.command_aliases = parse_command_aliases_cli_argument(
+    opts.command_aliases = parse_command_aliases_cli_arguments(
         opts.command_aliases,
     )
 
